==> centit-ip-users-register-5.2-20211020.084013-2-sources.jar: com/centit/framework/users/service/impl/PlatformServiceImpl.java <==
package com.centit.framework.users.service.impl;

import com.centit.framework.users.dao.PlatformDao;
import com.centit.framework.users.po.Platform;
import com.centit.framework.users.service.PlatformService;
import com.centit.support.database.utils.PageDesc;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Map;

/**
 * @author zfg
 */
@Service("platformService")
@Transactional
public class PlatformServiceImpl implements PlatformService {

    @Autowired
    private PlatformDao platformDao;

    @Override
    public List<Platform> listObjects(Map<String, Object> filterMap) {
        return platformDao.listObjects(filterMap);
    }

    @Override
    public List<Platform> listObjects(Map<String, Object> filterMap, PageDesc pageDesc) {
        return platformDao.listObjects(filterMap, pageDesc);
    }

    @Override
    public Platform getObjectById(String platId) {
        return platformDao.getObjectById(platId);
    }

    @Override
    public boolean hasSamePlat(Platform platform) {
        return platformDao.isUniquePlat(platform.getPlatSourceCode(), platform.getPlatId());
    }

    @Override
    public void savePlatform(Platform platform) {
        platformDao.saveNewObject(platform);
    }

    @Override
    public void updatePlatform(Platform platform) {
        platformDao.updateObject(platform);
    }

    @Override
    public void deletePlatform(Platform platform) {
        platformDao.deleteObjectById(platform.getPlatId());
    }
}

==> centit-ip-users-register-5.2-20220223.062205-27-sources.jar: com/centit/framework/users/service/impl/PlatformServiceImpl.java <==
package com.centit.framework.users.service.impl;

import com.centit.framework.users.dao.PlatformDao;
import com.centit.framework.users.po.Platform;
import com.centit.framework.users.service.PlatformService;
import com.centit.support.database.utils.PageDesc;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Map;

/**
 * @author zfg
 */
@Service("platformService")
@Transactional
public class PlatformServiceImpl implements PlatformService {

    @Autowired
    private PlatformDao platformDao;

    @Override
    public List<Platform> listObjects(Map<String, Object> filterMap) {
        return platformDao.listObjects(filterMap);
    }

    @Override
    public List<Platform> listObjects(Map<String, Object> filterMap, PageDesc pageDesc) {
        return platformDao.listObjects(filterMap, pageDesc);
    }

    @Override
    public Platform getObjectById(String platId) {
        return platformDao.getObjectById(platId);
    }

    @Override
    public Platform getPlatformByProperties(Map<String, Object> paramsMap) {
        return platformDao.getObjectByProperties(paramsMap);
    }

    @Override
    public boolean hasSamePlat(Platform platform) {
        return platformDao.isUniquePlat(platform.getPlatSourceCode(), platform.getPlatId());
    }

    @Override
    public void savePlatform(Platform platform) {
        platformDao.saveNewObject(platform);
    }

    @Override
    public void updatePlatform(Platform platform) {
        platformDao.updateObject(platform);
    }

    @Override
    public void deletePlatform(Platform platform) {
        platformDao.deleteObjectById(platform.getPlatId());
    }
}
